.. currentmodule:: fastdla.generators

==========
Generators
==========

.. autosummary::
   :toctree: ../generated
   :recursive:

   hea
   heisenberg_hva
   spin_glass
   tfim_hva
   z2lgt_hva
   spin_chain
